Module: Archsight::Annotations::Backup

Defined in:
lib/archsight/annotations/backup_annotations.rb

Overview

Backup module adds backup-related annotations to resource classes

Class Method Summary collapse

Class Method Details

.included(base) ⇒ Object



5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
# File 'lib/archsight/annotations/backup_annotations.rb', line 5

def self.included(base)
  base.class_eval do
    annotation "backup/mode",
               description: "Backup mode strategy",
               title: "Backup Mode",
               enum: %w[none full incremental continuous offsite not-needed]
    annotation "backup/rto",
               description: "Recovery Time Objective (RTO) in minutes - the maximum acceptable time to restore service after a failure",
               title: "Backup RTO (min)",
               type: Integer
    annotation "backup/rpo",
               description: "Recovery Point Objective (RPO) in minutes - the maximum acceptable amount of data loss measured in time",
               title: "Backup RPO (min)",
               type: Integer
  end
end