Class: Archsight::Resources::MotivationStakeholder

Inherits:
Base
  • Object
show all
Defined in:
lib/archsight/resources/motivation_stakeholder.rb

Overview

MotivationStakeholder represents the role of an individual, team, or organization that represents their interests in the effects of the architecture (ArchiMate Motivation Layer)

Instance Attribute Summary

Attributes inherited from Base

#path_ref, #raw, #references

Method Summary

Methods inherited from Base

#abandoned?, annotation, annotation_enum, annotation_format, annotation_matching, annotation_title, annotations, #annotations, computed_annotation, #computed_annotation_value, computed_annotations, description, discovered_annotations, filterable_annotations, #has_relations?, icon, include_annotations, inherited, #initialize, #kind, #klass, layer, list_annotations, matches_annotation_pattern?, #merge!, #metadata, #name, #raise, #referenced_by, #references_grouped, relation, relations, #relations, #relations_grouped, #set_computed_annotation, #set_relations, #spec, #to_s, #verb_allowed?, #verb_kind_allowed?, #verify!

Constructor Details

This class inherits a constructor from Archsight::Resources::Base